#include <stdlib.h>
#include <stdio.h>
#include <string.h>
#include <util/delay.h>
#include <avr/io.h>

#include "main.h"
#include "lcd.h"
#include "ledmatrix.h"
#include "mpu6050/mpu6050.h"
#include "max7219/max7219.h"

/*
    Ia date de la accelerometru si detecteaza directia
*/
void get_acc_direction() 
{   
	double ax, ay, az, gx, gy, gz;
    double LIMIT = 0.35;

	mpu6050_getConvData(&ax, &ay, &az, &gx, &gy, &gz);
	
	if (ax > LIMIT) {
		current_direction = DOWN;
	} else if (ax < -LIMIT) {
        current_direction = UP;
	}

	if (ay > LIMIT) {
        current_direction = RIGHT;
	} else if (ay < -LIMIT) {
        current_direction = LEFT;
	}
}

/* 
    Semnalizare dreapta
*/
void blink_right()
{
    setmatrix(first_right);
    _delay_ms(100);
    resetmatrix(0);

    setmatrix(second_right);
    _delay_ms(100);
    resetmatrix(0);

    setmatrix(third_right);
    _delay_ms(100);
    resetmatrix(0);
}

/* 
    Semnalizare stanga
*/
void blink_left()
{
    setmatrix(first_left);
    _delay_ms(100);
    resetmatrix(0);

    setmatrix(second_left);
    _delay_ms(100);
    resetmatrix(0);

    setmatrix(third_left);
    _delay_ms(100);
    resetmatrix(0);
}

/*
    Afiseaza pe matrice lumina pentru frana
*/
void blink_stop()
{
    setmatrix(stop);
    _delay_ms(300);
    resetmatrix(0);
}

int main (void)
{
    // Initializare module
	mpu6050_init();
    LCD_init();
    init();

    // Aprinde lumina din background de la LCD
	DDRC |= (1 << PC2);
	PORTC |= (1 << PC2);

    while (1) {
        // Se ia directia accelerometrului
        get_acc_direction();

        // Se afiseaza pe ecran si se semnalizeaza corespunzator
        LCD_writeInstr(LCD_INSTR_clearDisplay);
		LCD_writeInstr(LCD_INSTR_returnHome);

        switch (current_direction) {
			case UP:
        		LCD_print("STOPPING...");
                blink_stop();
				break;
			case DOWN:
        		LCD_print("GO AHEAD");
				break;
			case RIGHT:
        		LCD_print("GOING RIGHT");
                blink_right();
				break;
			case LEFT:
        		LCD_print("GOING LEFT");
                blink_left();
				break;
		}
        _delay_ms(300);
    }

    return 0;
}